--====================================================================
-- command processor
--====================================================================
-- called from telescope orientation function
-- as early as possible in per-frame processing
-- otherwise there are brief visual glitches as one thing changes
-- but others don't

-- previous selection: restore immediately after recognizing command

selP = nil

-- table of commands:
-- command text (name of selected object) = command function:

cmds = {
 Hale_Open_Cover  = OpenCover,
 HOC              = OpenCover,
 Hale_Close_Cover = CloseCover,
 HCC              = CloseCover,
-- cass 2ndary
 Hale_Lower_Cass = LowerCassUp,
 HLCA              = LowerCassUp,
 Hale_Raise_Cass = RaiseCassUp,
 HRCA              = RaiseCassUp,
-- coude 2ndary
 Hale_Lower_Coude  = LowerCoudeUp,
 HLCD              = LowerCoudeUp,
 Hale_Raise_Coude  = RaiseCoudeUp,
 HRCD              = RaiseCoudeUp,
 Hale_Lower_Crane = LowerCrane,
 HLC              = LowerCrane,
-- Central coude flat
 Hale_Raise_Crane = RaiseCrane,
 HRC              = RaiseCrane,
 Hale_Lower_Mirror = LowerMirror,
 HLM              = LowerMirror,
 Hale_Raise_Mirror = RaiseMirror,
 HRM              = RaiseMirror,

 Hale_CW_Coude_Mirror90 = CWMirror90,
 HCWM90              = CWMirror90,
 Hale_CCW_Coude_Mirror90 = CCWMirror90,
 HCCWM90              = CCWMirror90,


 Hale_Extend_Elevator = ExtElev,
 HEE              = ExtElev,
 Hale_Retract_Elevator = RetrElev,
 HRE              = RetrElev,


 Hale_Up_Elevator = UpElev,
 HUE              = UpElev,
 Hale_Down_Elevator = DownElev,
 HDE              = DownElev,
 Hale_Stop_Elevator = StopElev,
 HSE              = StopElev,


 Hale_Lower_Bridge = LowerBridge,
 HLBR              = LowerBridge,
 Hale_Raise_Bridge = RaiseBridge,
 HRBR              = RaiseBridge,

 Hale_Hide_Labels = HideLabels,
 HHLBL                 = HideLabels,
 Hale_Reveal_Labels = RevealLabels,
 HRLBL                 = RevealLabels,

 Hale_Hide_Telescope = HideTelescope,
 HHT                 = HideTelescope,
 Hale_Reveal_Telescope = RevealTelescope,
 HRT                 = RevealTelescope,

 Hale_Hide_PFC = HidePFC,
 HHPFC                 = HidePFC,
 Hale_Reveal_PFC = RevealPFC,
 HRPFC                 = RevealPFC,
 Hale_Reveal_Lores_Telescope = RevealLoresTelescope,
 HRLT                 = RevealLoresTelescope,

 Hale_Hide_Plinth = HidePlinth,
 HHP                 = HidePlinth,
 Hale_Reveal_Plinth = RevealPlinth,
 HRP                 = RevealPlinth,
 Hale_Reveal_Lores_Plinth = RevealLoresPlinth,
 HRLP                 = RevealLoresPlinth,

 Hale_Hide_Yoke = HideYoke,
 HHY                 = HideYoke,
 Hale_Reveal_Yoke = RevealYoke,
 HRY                 = RevealYoke,
 Hale_Reveal_Lores_Yoke = RevealLoresYoke,
 HRLY                 = RevealLoresYoke,

 Hale_Hide_Laser_Target = HideTarget,
 HHLTR                   = HideTarget,
 Hale_Reveal_Laser_Target = RevealTarget,
 HRLTR                     = RevealTarget,


 Hale_Hide_Laser_Beam = HideBeam,
 HHLB                   = HideBeam,
 Hale_Reveal_Laser_Beam = RevealBeam,
 HRLB                     = RevealBeam,


 Hale_Hide_AO = HideAO,
 HHAO                 = HideAO,
 Hale_Reveal_AO = RevealAO,
 HRAO                 = RevealAO,
 Hale_Hide_AOLight = HideAOLight,
 HHAOL                 = HideAOLight,
 Hale_Reveal_AOLight = RevealAOLight,
 HRAOL                 = RevealAOLight,

 Hale_Hide_LFCFOV = HideLFCFoV,
 HHLFCFOV                 = HideLFCFoV,
 Hale_Reveal_LFCFOV = RevealLFCFoV,
 HRLFCFOV                 = RevealLFCFoV,

 Hale_Hide_LFC = HideLFC,
 HHLFC                 = HideLFC,
 Hale_Reveal_LFC = RevealLFC,
 HRLFC                 = RevealLFC,

 Hale_Hide_LaunchTel = HideLaunchTel,
 HHLT                 = HideLaunchTel,
 Hale_Reveal_LaunchTel = RevealLaunchTel,
 HRLT                 = RevealLaunchTel,

 Hale_Hide_Base = HideBase,
 HHB                 = HideBase,
 Hale_Reveal_Base = RevealBase,
 HRB                 = RevealBase,
 Hale_Hide_Dome = HideDome,
 HHD                 = HideDome,
 Hale_Reveal_Dome = RevealDome,
 HRD                 = RevealDome,
 Hale_Open_Door = OpenDoor,
 HOD                 = OpenDoor,
 Hale_Close_Door = CloseDoor,
 HCD                 = CloseDoor,

 Hale_Forward_Overhead_Crane = FwdOCrane,
 HFOC = FwdOCrane,
 Hale_Back_Overhead_Crane    = BackOCrane,
 HBOC = BackOCrane,
 Hale_Stop_Overhead_Crane    = StopOCrane,
 HSOC = StopOCrane,

 Hale_Up_Hook = UpHook,
 HUH = UpHook,
 Hale_Down_Hook = DownHook,
 HDH = DownHook,
 Hale_Stop_Hook = StopHook,
 HSH = StopHook,

 Hale_Hide_Dome_Internal = HideDomeInternal,
 HHDI                 = HideDomeInternal,
 Hale_Reveal_Dome_Internal = RevealDomeInternal,
 HRDI                 = RevealDomeInternal,

 Hale_Hide_PrimeObs = HidePrimeObs,
 HHPO                 = HidePrimeObs,
 Hale_Reveal_PrimeObs = RevealPrimeObs,
 HRPO                 = RevealPrimeObs,

 Hale_Hide_Coude_Yoke_Mirror = HideCoudeYokeMirror,
 HHCYM                 = HideCoudeYokeMirror,
 Hale_Reveal_Coude_Yoke_Mirror = RevealCoudeYokeMirror,
 HRCYM                 = RevealCoudeYokeMirror,

 Hale_Hide_Coude_Mirror90 = HideCoudeMirror90,
 HHCM90                 = HideCoudeMirror90,
 Hale_Reveal_Coude_Mirror90 = RevealCoudeMirror90,
 HRCM90                 = RevealCoudeMirror90,

 Hale_Hide_Coude_Mirror = HideCoudeMirror0,
 HHCM0                 = HideCoudeMirror0,
 Hale_Reveal_Coude_Mirror = RevealCoudeMirror0,
 HRCM0                 = RevealCoudeMirror0,

-- had to resort to numbers to keep the lights & photons straight

Hale_Hide_Photons = HidePhotons,
HHPH                 = HidePhotons,
Hale_Fly_Photons1 = FlyPhoton1,
HFPH1                 = FlyPhoton1,
Hale_Fly_Photons2 = FlyPhoton2,
HFPH2                 = FlyPhoton2,
Hale_Fly_Photons3 = FlyPhoton3,
HFPH3                 = FlyPhoton3,
Hale_Fly_Photons4 = FlyPhoton4,
HFPH4                 = FlyPhoton4,
Hale_Fly_Photons5 = FlyPhoton5,
HFPH5                 = FlyPhoton5,

 Hale_Hide_Light = HideLight,
 HHL                 = HideLight,
 Hale_Reveal_Light1 = RevealLight1,
 HRL1                 = RevealLight1,
 Hale_Reveal_Light2 = RevealLight2,
 HRL2                 = RevealLight2,
 Hale_Reveal_Light3 = RevealLight3,
 HRL3                 = RevealLight3,
 Hale_Reveal_Light4 = RevealLight4,
 HRL4                 = RevealLight4,
 Hale_Reveal_Light5 = RevealLight5,
 HRL5                 = RevealLight5,

-- text messages because .cel print doesn't work
 Hale_Msg1 = Message1,
 Hale_Msg2 = Message2,
 Hale_Msg3 = Message3,
 Hale_Msg4 = Message4,
 Hale_Msg5 = Message5,
 Hale_Msg6 = Message6,
 Hale_Msg7 = Message7,
 }

hale_cmd = function (this_date)

  local sel = celestia:getselection()
  local sname = sel:name()

    todo = cmds[sname]
    if todo then 
	todo(this_date)
    	if (selP ~= nil) then celestia:select(selP) end -- restore previous selection

--  	local s = "Hale command:  name= "..sname
-- 	celestia:flash(s)
	return 1
    end

-- This selection is not recognized as a command: 
-- save it for reversion after next command

	selP = sel
	return 0
end
