--======================================================
-- rotation functions
--======================================================
coverRot = function ( date, numPanel )

-- orient around Y axis according to position around mirror
	q_rotateY = celestia:newrotation( yAxis, numPanel * math.pi/8.0 )

  	local Angle; 
	if     (date < cover.T0) 
	  then  Angle = cover.Th0
     	elseif (date < cover.T1)
      	  then	Angle = cover.Th0 + cover.V*(date-cover.T0)
	else    Angle = cover.Th1
      	end

-- current opening angle
	local q_rotate_now = celestia:newrotation( xAxis, Angle)

-- combine opening angle with orientation around mirror
	q_rotate = q_rotate_now  *q_rotateY
 	return q_rotate
end

-- ==========================================================
-- CoverRotate -- rotate mirror cover

CoverRotateProto = {
	Panel = 0,
}

-- constructor method

function CoverRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

	o.period = 1

	return o
end

-- orientation function

function CoverRotateProto:orientation(tjd)

	local qNow = coverRot( tjd, self.Panel )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function CoverRotate(sscvals)

	return CoverRotateProto:new(sscvals)

end




-----------------------------------------------------------------
-- Bridge up/down

BridgeRot = function ( date )

 	local Angle; 
	if     (date < Bridge.T0) 
	  then  Angle = Bridge.Th0
     	elseif (date < Bridge.T1)
      	  then	Angle = Bridge.Th0 + Bridge.V*(date-Bridge.T0)
	else    Angle = Bridge.Th1
      	end

 	return  zPi * celestia:newrotation( xAxis, Angle)
end

-- ==========================================================
-- BridgeRotate -- rotate mirror Bridge

BridgeRotateProto = { } -- no args

-- constructor method

function BridgeRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

	o.period = 1

	return o
end

-- orientation function

function BridgeRotateProto:orientation(tjd)

	local qNow = BridgeRot( tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function BridgeRotate(sscvals)

	return BridgeRotateProto:new(sscvals)

end

-----------------------------------------------------------------
-- object (coude or cass) rotation about x axis

ObjRotXY = function (obj, date )

	local Angle; 
	if     (date < obj.T0) 
	  then  Angle = obj.Th0
     	elseif (date < obj.T1)
      	  then	Angle = obj.Th0 + obj.V*(date-obj.T0)
	else    Angle = obj.Th1
      	end

	return obj.RotY * celestia:newrotation( xAxis, Angle)
end

-----------------------------------------------------------------
-- object (coude mirror90, elevator) rotation about Y axis

ObjRotY = function (obj, date )

	local Angle; 
	if     (date < obj.T0) 
	  then  Angle = obj.Th0
     	elseif (date < obj.T1)
      	  then	Angle = obj.Th0 + obj.V*(date-obj.T0)
	else    Angle = obj.Th1
      	end

	return yPi * celestia:newrotation( yAxis, Angle)
end

-----------------------------------------------------------------
-- object (crane, mirror or elevator) rotation about X axis

ObjRotX = function (obj, date )

	local Angle; 
	if     (date < obj.T0) 
	  then  Angle = obj.Th0
     	elseif (date < obj.T1)
      	  then	Angle = obj.Th0 + obj.V*(date-obj.T0)
	else    Angle = obj.Th1
      	end

	obj.ThNow = Angle

	return yPi * celestia:newrotation( xAxis, Angle)
end


-- ==========================================================
-- cassUpRotate -- rotate mirror cassUp

cassUpRotateProto = { } -- no args

-- constructor method

function cassUpRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

	o.period = 1

	return o
end

-- orientation function

function cassUpRotateProto:orientation(tjd)

	local qNow = ObjRotXY( cassUp, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function CassUpRotate(sscvals)

	return cassUpRotateProto:new(sscvals)

end



-- ==========================================================
-- coudeUpRotate -- rotate mirror coudeUp

coudeUpRotateProto = { } -- no args

-- constructor method

function coudeUpRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

	o.period = 1

	return o
end

-- orientation function

function coudeUpRotateProto:orientation(tjd)

	local qNow = ObjRotXY( coudeUp, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function CoudeUpRotate(sscvals)

	return coudeUpRotateProto:new(sscvals)

end



-- ==========================================================
-- craneRotate -- rotate mirror crane

craneRotateProto = { } -- no args

-- constructor method

function craneRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

	o.period = 1

	return o
end

-- orientation function

function craneRotateProto:orientation(tjd)

	local qNow = ObjRotX( crane, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function CraneRotate(sscvals)

	return craneRotateProto:new(sscvals)

end


-- ==========================================================
-- mirrorRotate -- rotate coude mirror

mirrorRotateProto = { } -- no args

-- constructor method

function mirrorRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

 	o.period = 1

	return o
end

-- orientation function

function mirrorRotateProto:orientation(tjd)

	local qNow = ObjRotX( mirror, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function MirrorRotate(sscvals)

	return mirrorRotateProto:new(sscvals)

end

-- ==========================================================
-- mirror90Rotate -- rotate coude mirror90

mirror90RotateProto = { } -- no args

-- constructor method

function mirror90RotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

 	o.period = 1

	return o
end

-- orientation function

function mirror90RotateProto:orientation(tjd)

	local qNow = ObjRotY( mirror90, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function Mirror90Rotate(sscvals)

	return mirror90RotateProto:new(sscvals)

end
-- ==========================================================
-- ElevatorRotate -- rotate Elevator

ElevatorRotateProto = { } -- no args

-- constructor method

function ElevatorRotateProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

 	o.period = 1

	return o
end

-- orientation function

function ElevatorRotateProto:orientation(tjd)

	local qNow = ObjRotY( Elevator, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function ElevatorRotate(sscvals)

	return ElevatorRotateProto:new(sscvals)

end


-- ==========================================================
-- ElevatorRaiseLower -- Raise/lower Elevator

ElevatorRaiseLowerProto = { } -- no args

-- constructor method

function ElevatorRaiseLowerProto:new(o)
	o = o or {}
	setmetatable (o, self)
	self.__index = self

 	o.period = 1

	return o
end

-- orientation function

function ElevatorRaiseLowerProto:orientation(tjd)

	local qNow = ObjRotX( ElevatorUpDown, tjd )
	return qNow.w, qNow.x, qNow.y, qNow.z

end

-- create new rotation object

function ElevatorRaiseLower(sscvals)

	return ElevatorRaiseLowerProto:new(sscvals)

end

